# senfenico-python
# Official Senfenico Bindings for Python

A Python library for Senfenico's API.

## Setup

You can install this package by using the pip tool and installing:

```bash
$ pip install senfenico
```

Or:

```bash
$ easy_install senfenico
```

## Setting up a Senfenico Account

Sign up for Senfenico at [https://api.senfenico.com/user_dashboard/register/](https://api.senfenico.com/user_dashboard/register/).

## Using the Senfenico API

Documentation for the python bindings can be found alongside Senfenico's other bindings here:

- [https://docs.senfenico.com/en/](https://docs.senfenico.com/en/)
